@@ -34,7 +34,7 @@
 	_(pfx, COLOUR_DIFF_META),				\
 	_(pfx, COLOUR_DIFF_MINUS),				\
 	_(pfx, COLOUR_DIFF_PLUS),				\
-	_(pfx, COLOUR_DIFF_CHUNK),				\
+	_(pfx, COLOUR_DIFF_HUNK),				\
 	_(pfx, COLOUR_DIFF_TAGS),				\
 	_(pfx, COLOUR_DIFF_SBS_EDIT),				\
 	_(pfx, COLOUR_TREE_LINK),				\
@@ -78,7 +78,7 @@
 	_(pfx, DIFF_PLUS),					\
 	_(pfx, DIFF_EDIT),					\
 	_(pfx, DIFF_CONTEXT),					\
-	_(pfx, DIFF_CHUNK),					\
+	_(pfx, DIFF_HUNK),					\
 	_(pfx, DIFF_SEPARATOR)
 
 #define VIEW_MODE_ENUM(pfx, _)					\
